@@ -15,12 +15,9 @@
 #define BUS_NAME "com.nokia.csd.Call"
 #define BUS_PATH "/com/nokia/csd/call"
 #define INSTANCE_INTERFACE "com.nokia.csd.Call.Instance"
-
 #define DEFAULT_WHITELIST "/home/user/MyDocs/whitelist.txt"
 #define DEFAULT_BLACKLIST "/home/user/MyDocs/blacklist.txt"
 
-
-
 class CallerXDaemon : public QObject
 {
     Q_OBJECT
@@ -44,7 +41,7 @@ public slots:
     Q_SCRIPTABLE void addrecentnumber();
 
 private slots:
-    void callScreen(const QDBusObjectPath&, const QDBusMessage&);
+    void callScreen(const QDBusObjectPath&, const QString&);
     void callRelease(const QString&);
     void loadlist();
     void setloadlist(const QString&, bool m);
